package jp.veritrans.tercerog.sample.command.carrier;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierCancelResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * CarrierCancelCommand : キャリア決済(キャンセル)サンプル
 */
public class CarrierCancelCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // キャリア
        String carrier = "au";
        // 取引ID(与信時に利用したものを設定してください)
        String orderID = "1234567890";
        // 課金取消月
        String cancelMonth = "";
        // 金額
        String amount = "";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        CarrierCancelRequestDto reqDto = new CarrierCancelRequestDto();
        // キャリア
        reqDto.setServiceOptionType(carrier);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 課金取消月の設定
        reqDto.setCancelMonth(cancelMonth);
        // 金額の設定
        reqDto.setAmount(amount);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        CarrierCancelResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CarrierCancelResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Carrier(Cancel) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Cancel Month", cancelMonth);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Balance", resDto.getBalance());
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("CancelDatetime", resDto.getCancelDatetime());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
