package jp.veritrans.tercerog.sample.command.carrier;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * CarrierReAuthorizeCommand : キャリア決済(限度額確保要求)サンプル
 */
public class CarrierReAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // キャリア
        String carrier = "docomo";
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 元取引ID(対象とする過去の取引IDを指定)
        String originalOrderID = "sample001";
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 金額
        String amount = Custom.getAmount();

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        CarrierReAuthorizeRequestDto reqDto = new CarrierReAuthorizeRequestDto();
        // キャリア
        reqDto.setServiceOptionType(carrier);
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(originalOrderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        CarrierReAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CarrierReAuthorizeResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Carrier(ReAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Carrier", carrier);
            Custom.print("Order ID", orderID);
            Custom.print("Original Order ID", originalOrderID);
            Custom.print("With Capture", withCapture);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Txn Time", resDto.getTxnTime());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
