package jp.veritrans.tercerog.sample.command.linepay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.LinepayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.LinepayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * LinepayAuthorizeCommand : LINE Pay(与信)サンプル
 */
public class LinepayAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 決済確認方法(0:ブラウザを介する通信、1:サーバ間通信)
        String paymentConfirmType = "0";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        LinepayAuthorizeRequestDto reqDto = new LinepayAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品番号
        reqDto.setItemId("123456");
        // 商品名
        reqDto.setItemName("sample商品");
        // 決済確認方法
        reqDto.setPaymentConfirmType(paymentConfirmType);
        // ワンタイムキー(指定時、決済確認方法は1:サーバ間通信)
        // reqDto.setOneTimeKey("123456789012");

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        LinepayAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (LinepayAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Linepay(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("PaymentConfirmType", paymentConfirmType);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Redirect Web Url", resDto.getRedirectWebUrl());
            Custom.print("Redirect App Url", resDto.getRedirectAppUrl());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
