package jp.veritrans.tercerog.sample.command.masterpass;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MasterpassLoginRequestDto;
import jp.veritrans.tercerog.mdk.dto.MasterpassLoginResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * MasterpassLoginCommand : Masterpass決済(課金申込)サンプル
 */
public class MasterpassLoginCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 合計金額(自動取得)
        String itemAmount = Custom.getAmount();

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        MasterpassLoginRequestDto reqDto = new MasterpassLoginRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 表示用商品説明1の設定
        reqDto.setDescription1("sample商品");
    	// 表示用商品数量1の設定
        reqDto.setQuantity1("1");
    	// 表示用商品金額1の設定
        reqDto.setValue1(itemAmount);
        // 合計金額の設定
        reqDto.setItemAmount(itemAmount);
        // 商品番号の設定
        reqDto.setItemId("123456");

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        MasterpassLoginResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (MasterpassLoginResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Masterpass(Login) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("itemAmount", itemAmount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
