package jp.veritrans.tercerog.sample.command.paypay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.PaypayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PaypayAuthorizeCommand : PayPayオンライン決済(決済申込)サンプル
 */
public class PaypayOnlineAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // サービスオプションタイプ：オンライン
        String serviceOptionType = MdkServiceConstants.PAYPAY_ONLINE;
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 商品ID
        String itemId = "123456";
        // 決済完了時URL
        String successUrl = "http://localhost/web/paypay/Result?result=SUCCESS";
        // 決済キャンセル時URL
        String cancelUrl = "http://localhost/web/paypay/Result?result=CANCEL";
        // 決済エラー時URL
        String errorUrl = "http://localhost/web/paypay/Result?result=ERROR";
        // プッシュ先URL
        String pushUrl = "http://localhost/web/push/paypayPush";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        PaypayAuthorizeRequestDto reqDto = new PaypayAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品IDの設定
        reqDto.setItemId(itemId);
        // 決済完了時URLの設定
        reqDto.setSuccessUrl(successUrl);
        // 決済キャンセル時URLの設定
        reqDto.setCancelUrl(cancelUrl);
        // 決済エラー時URLの設定
        reqDto.setErrorUrl(errorUrl);
        // プッシュ先URLの設定
        reqDto.setPushUrl(pushUrl);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        PaypayAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (PaypayAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- paypay(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("ItemId", itemId);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Response Contents", resDto.getResponseContents());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
