package jp.veritrans.tercerog.sample.command.paypay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.PaypayCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypayCaptureResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PaypayCaptureCommand : paypayオンライン決済(売上)サンプル
 */
public class PaypayOnlineCaptureCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(決済申込時に利用したものを設定してください)
        String orderID = "1234567890";
        // サービスオプションタイプ：オンライン
        String serviceOptionType = MdkServiceConstants.PAYPAY_ONLINE;
        // 売上金額
        String amount = Custom.getAmount();
        // 注文の説明
        String orderDescription = "注文の説明";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        PaypayCaptureRequestDto reqDto = new PaypayCaptureRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 売上金額の設定
        reqDto.setAmount(amount);
        // 注文の説明の設定
        reqDto.setOrderDescription(orderDescription);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        PaypayCaptureResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (PaypayCaptureResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- paypay(Capture) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Order Description", orderDescription);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Balance", resDto.getBalance());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
