package jp.veritrans.tercerog.sample.command.paypay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.PaypayRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypayRefundResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PaypayRefundCommand : paypayオンライン決済(返金)サンプル
 */
public class PaypayOnlineRefundCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(決済申込時に利用したものを設定してください)
        String orderID = "1234567890";
        // サービスオプションタイプ：バーコード
        String serviceOptionType = MdkServiceConstants.PAYPAY_ONLINE;
        // 返金金額
        String amount = Custom.getAmount();

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        PaypayRefundRequestDto reqDto = new PaypayRefundRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 返金金額の設定
        reqDto.setAmount(amount);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        PaypayRefundResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (PaypayRefundResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- paypay(Refund) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Balance", resDto.getBalance());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
