package jp.veritrans.tercerog.sample.command.rakuten;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RakutenUpdateAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.RakutenUpdateAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * RakutenUpdateAuthorizeCommand : 楽天ID決済(与信変更)サンプル
 */
public class RakutenUpdateAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(与信時に利用したものを設定してください)
        String orderID = "1234567890";
        // 金額
        String amount = "100";
        // 与信延長フラグ
        String authExtensionFlag = MdkServiceConstants.RAKUTEN_AUTH_EXTENSION_TRUE;

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        RakutenUpdateAuthorizeRequestDto reqDto = new RakutenUpdateAuthorizeRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 与信延長フラグの設定
        reqDto.setAuthExtensionFlag(authExtensionFlag);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        RakutenUpdateAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RakutenUpdateAuthorizeResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Rakuten(UpdateAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Auth Extension Flag", authExtensionFlag);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Transaction Datetime", resDto.getTransactionDatetime());
            Custom.print("Rakuten Order Id", resDto.getRakutenOrderId());
            Custom.print("Gateway Order Id", resDto.getGatewayOrderId());
            Custom.print("Used Point", resDto.getUsedPoint());
            Custom.print("Cancel Expiration Time", resDto.getCancelExpirationTime());
            Custom.print("Capture Expiration Time", resDto.getCaptureExpirationTime());
            Custom.print("Update Expiration Time", resDto.getUpdateExpirationTime());
            Custom.print("Extend Auth Expiration Time", resDto.getExtendAuthExpirationTime());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
