package jp.veritrans.tercerog.sample.command.recruit;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RecruitAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecruitAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * RecruitAuthorizeCommand : リクルートかんたん支払い(与信)サンプル
 */
public class RecruitAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        RecruitAuthorizeRequestDto reqDto = new RecruitAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品番号
        reqDto.setItemId("123456");
        // 商品名
        reqDto.setItemName("sample商品");

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        RecruitAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RecruitAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Recruit(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Redirect Url", resDto.getRedirectUrl());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
