package jp.veritrans.tercerog.sample.util;

import java.io.File;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Hashtable;
import java.util.Map;
import java.util.StringTokenizer;

/**
 * Custom : 取引IDや金額生成など、お客様カスタマイズ用クラス
 */
public class Custom {

    /**
    * 取引IDを取得します。
    * デフォルトではシステム時間(ミリ秒まで)を取引IDとして返します。
    * お客様実装時にECサイトショーピングカートと連動してください。
    * @return 取引ID
    */
    static public String getOrderID() {
        String orderID = String.valueOf(System.currentTimeMillis());
        return orderID;
    }

    /**
    * 取引金額を取得します。
    * デフォルトでは 100円 を返します。
    * お客様実装時にECサイトショーピングカートと連動してください。
    * @return 金額
    */
    static public String getAmount() {
        String amount = "100";
        return amount;
    }

    /**
    * 決済の結果を出力する。
    * @param msg 出力用メッセージ
    */
    static public void print(String msg) {
        if (msg == null || msg.length() == 0) msg = "";
        System.out.println(msg);
    }

    /**
    * 決済の結果を出力する。
    * @param tag 出力メッセージのタグ名
    * @param msg 出力用メッセージ
    */
    static public void print(String tag, String msg) {
        if (tag == null || tag.length() == 0) msg = "";
        if (msg == null || msg.length() == 0) msg = "";
        System.out.println("[" + tag + "]: " + msg);
    }

    /**
     * 支払期限を取得する。
     * 店舗様のポリシーによってカスタマイズしてください。
     * @param dateFormat 日付(時刻)文字列のフォーマット
     *         "yyyy/MM/dd" - コンビニ決済の支払期限設定用
     *         "yyyyMMddHHmmss" - 電子マネー決済の決済期限設定用
     *         "yyyyMMdd" - 銀行決済の支払期限設定用
     * @param noOfDaysFromToday システム日付より加算される日数
     * @return (システム日付 + noOfDaysFromToday日)の日付をdateFormatに定義された文字列で返す
     */
    static public String getPaymentLimit(String dateFormat, int noOfDaysFromToday) {
        SimpleDateFormat formatter2 = new SimpleDateFormat(dateFormat);
        Calendar cal = Calendar.getInstance();
        cal.add(Calendar.DATE, noOfDaysFromToday);
        return formatter2.format(cal.getTime());
    }

    /**
     * システム日付(YYYYMMDD)を取得する。
     * @return YYYYMMDD形式のシステム日付文字列
     */
    static public String getSystemDate() {
        SimpleDateFormat formatter2 = new SimpleDateFormat("yyyyMMdd");
        Calendar cal = Calendar.getInstance();
        return formatter2.format(cal.getTime());
    }


    /**
    * ボディからのパラメータを取得する。
    *
    * @param body　ゲートウェイの電文ボディ
    * @return ボディからのパラメータを入っているマップ
    */
    static public Map getParametersFromBody(String body) throws UnsupportedEncodingException{
        StringTokenizer tokenizer = new StringTokenizer(body, "&");
        Hashtable hashtable = new Hashtable();
        while (tokenizer.hasMoreTokens()) {
            String pair = tokenizer.nextToken();
            int index = pair.indexOf("=");
            if (index == -1)
                continue;
            String key = pair.substring(0, index);
            String value = URLDecoder.decode(pair.substring(index + 1), "UTF-8");
            hashtable.put(key, value);
        }
        return hashtable;
    }

    /**
    * ディレクトリを作成する。
    *
    * @param outputDirectory　作成したいディレクトリのパス
    */
    static public void createDirectoryIfRequired(String outputDirectory) {
        File theDir = new File(outputDirectory);
        if (!theDir.exists()) {
            theDir.mkdir();
        }
    }

    /**
    * ファイルの絶対パスを作成する。
    *
    * @param serviceName サービス名
    * @param outputDirectory ディレクトリ
    * @param pushTime 送信時刻
    * @param pushId 識別ID
    * @return ファイルの絶対パス
    */
    static public String getFilePath(String serviceName, String outputDirectory, String pushTime, String pushId) {
        StringBuffer path = new StringBuffer(outputDirectory);
        if (!outputDirectory.endsWith(File.separator))
            path.append(File.separator);
        path.append(serviceName);
        path.append("-");
        path.append(pushTime);
        path.append("-");
        path.append(pushId);
        path.append(".csv");
        return path.toString();
    }

}
