package jp.veritrans.tercerog.sample.web;

import java.io.IOException;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.sample.util.Utils;

/**
 * サーブレットの基底共通クラス。 サーブレットとしての機能をまとめたクラス。
 */
public abstract class MdkSampleBaseServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;

    /** 環境のエンコーディング */
    private static final String DEFAULT_CHARACTER = "UTF-8";

    /**
     * 継承しているクラスは以下のメソッドに処理を実装すること。 各サーブレットの業務処理を記述する。
     *
     * @param request リクエスト情報
     * @param response レスポンス情報
     * @throws ServletException
     * @throws IOException
     */
    protected abstract void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException;

    /**
     * @see HttpServlet#HttpServlet()
     */
    public MdkSampleBaseServlet() {
        super();
    }

    /**
     * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        settingAndNextProcess(request, response);
    }

    /**
     * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        settingAndNextProcess(request, response);
    }

    /**
     * 環境的なセッティングを行い、当クラスを継承している子クラスのdoProcessメソッドを呼ぶ。
     *
     * @param request リクエスト情報
     * @param response レスポンス情報
     * @throws ServletException
     * @throws IOException
     */
    private void settingAndNextProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html; charset=" + DEFAULT_CHARACTER);
        request.setCharacterEncoding(DEFAULT_CHARACTER);
        doProcess(request, response);
    }

    /**
     * パラメータがnull(空文字を含む)でないかをチェックする。
     *
     * @param param 検査したい文字列。
     * @return nullの場合はtrueを返す。
     */
    protected boolean isNull(String param) {
        return Utils.isNull(param);
    }

    /**
     * サーブレットからJSPを呼び出す。
     *
     * @param request リクエスト情報
     * @param response レスポンス情報
     * @param sendUri 呼び出すURI
     * @throws ServletException
     * @throws IOException
     */
    protected void forward(HttpServletRequest request, HttpServletResponse response, String sendUri)
            throws ServletException, IOException {
        RequestDispatcher dispathcer = request.getRequestDispatcher(sendUri);
        dispathcer.forward(request, response);
    }
}
