package jp.veritrans.tercerog.sample.web.alipay;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipayRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.AlipayRefundResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * Alipay決済の返金処理クラス。
 */
public class RefundExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */

    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        String orderNumber = request.getParameter("orderId");
        String amount = request.getParameter("amount");
        String reason = request.getParameter("reason");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderNumber)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } 
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Refund.jsp");
            return;
        }
        AlipayRefundRequestDto reqDto = new AlipayRefundRequestDto();
        reqDto.setOrderId(orderNumber);
        reqDto.setAmount(amount);
        reqDto.setReason(reason);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            AlipayRefundResponseDto resDto = (AlipayRefundResponseDto)tran.execute();

            // 決済結果表示画面用のパラメータ設定
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("centerTradeId", resDto.getCenterTradeId());
            request.setAttribute("balance", resDto.getBalance());

            // 解析画面を表示します
            forward(request, response, "./RefundExec.jsp");
        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./RefundExec.jsp");
        }
    }
}
