package jp.veritrans.tercerog.sample.web.amazonpay;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AmazonpayGetAddressRequestDto;
import jp.veritrans.tercerog.mdk.dto.AmazonpayGetAddressResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * AmazonPay 住所情報取得請求処理クラス。
 */
public class GetAddressExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./GetAddress.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        AmazonpayGetAddressRequestDto reqDto = new AmazonpayGetAddressRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            AmazonpayGetAddressResponseDto resDto = (AmazonpayGetAddressResponseDto)tran.execute();

            // 結果画面を表示します
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());

            request.setAttribute("centerResponseDatetime", resDto.getCenterResponseDatetime());
            request.setAttribute("shippingName", resDto.getShippingName());
            request.setAttribute("shippingPhone", resDto.getShippingPhone());
            request.setAttribute("shippingAddress1", resDto.getShippingAddress1());
            request.setAttribute("shippingAddress2", resDto.getShippingAddress2());
            request.setAttribute("shippingAddress3", resDto.getShippingAddress3());
            request.setAttribute("shippingPrefecture", resDto.getShippingPrefecture());
            request.setAttribute("shippingPostalCode", resDto.getShippingPostalCode());

            forward(request, response, "./GetAddressExec.jsp");
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./GetAddressExec.jsp");
        }
    }

}
