package jp.veritrans.tercerog.sample.web.carrier.base;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierReAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * キャリア決済処限度額確保要求処理クラス。
 */
public abstract class AbstractReAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();

    abstract protected String getReAuthorizeJsp();

    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // サービスオプションタイプ（キャリアの種類）の取得
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 元取引IDの取得
        String originalOrderId = request.getParameter("originalOrderId");
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 与信同時売上フラグの取得
        String withCapture = request.getParameter("withCapture");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(originalOrderId)) {
            warning = "<font color='#ff0000'><b>必須項目：元取引IDが指定されていません</b></font>";
        } else if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getReAuthorizeJsp());
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CarrierReAuthorizeRequestDto reqDto = new CarrierReAuthorizeRequestDto();

        // サービスオプションタイプ（キャリアの種類）の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(originalOrderId);
        // TODO:ダミーログ
        System.out.println(originalOrderId);
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 与信同時売上フラグの設定
        if (MdkServiceConstants.CARRIER_AUTH_WITH_CAPTURE.equals(withCapture)) {
            reqDto.setWithCapture("true");
        }

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CarrierReAuthorizeResponseDto resDto = (CarrierReAuthorizeResponseDto)tran.execute();

            // 結果画面を表示します
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("txnTime", resDto.getTxnTime());
            request.setAttribute("crOrderId", resDto.getCrOrderId());

            forward(request, response, getJsp());

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, getJsp());
        }
    }
}
