package jp.veritrans.tercerog.sample.web.em;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmCancelResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 電子マネー決済 取消請求処理クラス。
 */
public class CancelExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 取引ID
        String orderId = request.getParameter("orderId");
        // オーダー種別
        String orderKind = request.getParameter("orderKind");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }

        if ("tcc-redirect".equals(serviceOptionType)) {
            if (!isNull(orderKind)) {
                warning = "<font color='#ff0000'><b>対象取引種別は指定できません</b></font>";
            }
        } else {
            if (isNull(orderKind)) {
                warning = "<font color='#ff0000'><b>必須項目：対象取引種別が指定されていません</b></font>";
            }
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Cancel.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        EmCancelRequestDto reqDto = new EmCancelRequestDto();
        // 取引IDの設定
        // パラメタから取得した値を設定
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setOrderId(orderId);
        reqDto.setOrderKind(orderKind);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            EmCancelResponseDto resDto = (EmCancelResponseDto) transaction.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());

            // 結果画面を表示します
            forward(request, response, "./CancelExec.jsp");

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./CancelExec.jsp");
        }
    }
}
