package jp.veritrans.tercerog.sample.web.em;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmRemoveRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmRemoveResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 電子マネー決済　カード情報削除処理クラス。
 */
public class RemoveExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // ユーザID
        String userId = request.getParameter("userId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        // ユーザID
        if ("tcc-redirect".equals(serviceOptionType)) {
            if (isNull(userId) == true) {
                warning = "<font color='#ff0000'><b>必須項目：ユーザIDが指定されていません</b></font>";
            }
        } else {
            if (isNull(userId) == false) {
                warning = "<font color='#ff0000'><b>ユーザIDは指定できません</b></font>";
            }
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Remove.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        EmRemoveRequestDto reqDto = new EmRemoveRequestDto();
        // パラメタから取得した値を設定
        reqDto.setOrderId(orderId);
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setUserId(userId);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            EmRemoveResponseDto resDto = (EmRemoveResponseDto) transaction.execute();

            request.setAttribute("orderKind", "remove");
            request.setAttribute("serviceOptionType", serviceOptionType);
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode() != null ? resDto.getVResultCode() : "");
            request.setAttribute("mErrMsg", resDto.getMerrMsg() != null ? resDto.getMerrMsg() : "");
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("deleteCardNum", resDto.getDeleteCardNum());

            // 結果画面を表示します
            forward(request, response, "./RemoveExec.jsp");

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./RemoveExec.jsp");
        }
    }
}
