package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AccountDeleteRequestDto;
import jp.veritrans.tercerog.mdk.dto.AccountDeleteResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 会員退会処理クラス
 */
public class AccountWithdrawExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // 退会年月日の取得
        String deleteDate = request.getParameter("deleteDate");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        // 会員ID
        if (isNull(accountId) == true) {
            warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./AccountWithdraw.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        AccountDeleteRequestDto reqDto = new AccountDeleteRequestDto();
        // 会員ID設定
        reqDto.setAccountId(accountId);
        // 退会年月日設定
        reqDto.setDeleteDate(deleteDate);

        /* ******************** */
        /* 強制退会する場合に設定    */
        /* ******************** */
        //reqDto.setForceWithdraw("1");

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            AccountDeleteResponseDto resDto = (AccountDeleteResponseDto) transaction.execute();

            if (resDto.getPayNowIdResponse() != null) {
                request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
            }
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());

            // 結果画面を表示します
            forward(request, response, "./AccountWithdrawExec.jsp");

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response,  "./AccountWithdrawExec.jsp");
        }

    }

}
