package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * カード決済実行処理(本人認証なし)
 */
public class CardAuthorizeExec extends MdkSampleBaseServlet {

    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 金額
        String amount = request.getParameter("amount");
        // 与信方法
        String withCapture = request.getParameter("withCapture");
        // カードID
        String cardId = request.getParameter("cardId");
        // 支払方法
        String jpo1 = request.getParameter("jpo1");
        // 支払い回数
        String jpo2 = request.getParameter("jpo2");
        // セキュリティコード
        String securityCode = request.getParameter("secureCd");
        // カード番号
        String cardNumber = request.getParameter("cardNumber");
        // 有効期限
        String cardExpire = request.getParameter("cardExpire");
        // 会員ID
        String accountId = request.getParameter("accountId");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./CardAuthorizeExec.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CardAuthorizeRequestDto reqDto = new CardAuthorizeRequestDto();

        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // カード番号
        reqDto.setCardNumber(cardNumber);
        // 有効期限
        reqDto.setCardExpire(cardExpire);
        // ペイメントオプション(支払方法・回数)の設定
        String jpo = null;
        if ("10".equals(jpo1) || "80".equals(jpo1)) {
            jpo = jpo1;
        } else if ("61".equals(jpo1) && jpo2 != null) {
            jpo = jpo1 + "C" + jpo2;
        }
        if (jpo != null) reqDto.setJpo(jpo);
        // セキュリティコード設定
        if (securityCode != null) reqDto.setSecurityCode(securityCode);
        // 与信方法によって、売上フラグを設定
        if ("1".equals(withCapture)) reqDto.setWithCapture("true");

        //会員ID
        reqDto.setAccountId(accountId);
        //カードID
        reqDto.setCardId(cardId);

        /* ******************************************* */
        /* 標準カードフラグを設定する場合に設定(未設定時は1)   */
        /* ******************************************* */
        //reqDto.setDefaultCard("1");

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CardAuthorizeResponseDto resDto = (CardAuthorizeResponseDto) tran.execute();

            if (resDto.getPayNowIdResponse() != null) {
                request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());                
            }
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());

            // 結果画面を表示します
            forward(request, response, "./CardAuthorizeExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./CardAuthorizeExec.jsp");
        }

    }

}
