package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 決済＋会員入会処理クラス
 */
public class EntryAndCardExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 与信方法の取得
        String withCapture = request.getParameter("withCapture");
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 支払方法の取得
        String jpo1 = request.getParameter("jpo1");
        // 支払回数の取得
        String jpo2 = request.getParameter("jpo2");
        // トークンの取得
        String token = request.getParameter("token");
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // 課金グループIDの取得
        String groupId = request.getParameter("groupId");
        // 課金開始日の取得
        String startDate = request.getParameter("startDate");
        // 課金終了日の取得
        String endDate = request.getParameter("endDate");
        // 都度／初回課金金額の取得
        String oneTimeAmount = request.getParameter("oneTimeAmount");
        // 継続課金金額の取得
        String recurringAmount = request.getParameter("recurringAmount");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./EntryAndCard.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CardAuthorizeRequestDto reqDto = new CardAuthorizeRequestDto();

        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // ペイメントオプション(支払方法・回数)の設定
        String jpo = null;
        if ("10".equals(jpo1) || "80".equals(jpo1)) {
            jpo = jpo1;
        } else if ("61".equals(jpo1) && jpo2 != null) {
            jpo = jpo1 + "C" + jpo2;
        }
        if (jpo != null) reqDto.setJpo(jpo);
        // トークン設定
        reqDto.setToken(token);
        // 与信方法によって、売上フラグを設定
        if ("1".equals(withCapture)) reqDto.setWithCapture("true");

        reqDto.setAccountId(accountId);
        reqDto.setGroupId(groupId);
        reqDto.setStartDate(startDate);
        reqDto.setEndDate(endDate);
        reqDto.setOneTimeAmount(oneTimeAmount);
        reqDto.setRecurringAmount(recurringAmount);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CardAuthorizeResponseDto resDto = (CardAuthorizeResponseDto) tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            if (resDto.getPayNowIdResponse() != null) {
                request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
            }

            // 結果画面を表示します
            forward(request, response, "./EntryAndCardExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./EntryAndCardExec.jsp");
        }
    }

}
