package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;
import java.util.HashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardInfo;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetResponseDto;
import jp.veritrans.tercerog.mdk.dto.RecurringAddRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringAddResponseDto;
import jp.veritrans.tercerog.mdk.dto.RecurringUpdateRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringUpdateResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;
import org.apache.commons.lang.StringUtils;

/**
 * 継続課金(カード払い)管理処理クラス
 */
public class RecurringExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        HttpSession session = request.getSession(true);
        String warning = null;
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 処理モードの取得
        String execMode = request.getParameter("execMode");
        // 課金処理モードの取得
        String chargeMode = request.getParameter("chargeMode");
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // 課金グループIDの取得
        String groupId = request.getParameter("groupId");
        // 課金開始日の取得
        String startDate = request.getParameter("startDate");
        // 課金終了日の取得
        String endDate = request.getParameter("endDate");
        // 都度／初回課金金額の取得
        String oneTimeAmount = request.getParameter("oneTimeAmount");
        // 継続課金金額の取得
        String amount = request.getParameter("amount");
        // カード選択の取得
        String cardSelect = request.getParameter("cardSelect");
        session.setAttribute("cardSelect", cardSelect);
        // トークンの取得
        String token = request.getParameter("token");

        if ("1".equals(execMode)) {

            // カード情報取得  //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./Recurring.jsp");
                return;
            }
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            CardInfoGetRequestDto reqDto = new CardInfoGetRequestDto();
            reqDto.setAccountId(accountId);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                CardInfoGetResponseDto resDto = (CardInfoGetResponseDto) tran.execute();

                // 処理結果を取得する
                String mStatus = resDto.getMstatus();

                if ("success".equals(mStatus)) {
                    CardInfo[] cardInfos = resDto.getPayNowIdResponse().getAccount().getCardInfo();
                    HashMap map = new HashMap();
                    // カード情報分繰り返す
                    for (int i=0; i < cardInfos.length; i++) {
                        map.put(cardInfos[i].getCardId(),
                                cardInfos[i].getCardNumber() + "：" + cardInfos[i].getCardExpire());
                    }
                    session.setAttribute("cardList", map);
                    session.setAttribute("cardSelect", "");

                    // 結果画面を表示します
                    forward(request, response, "./Recurring.jsp");

                } else {
                    if(resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());
                    forward(request, response, "./RecurringExec.jsp");
                }

            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./RecurringExec.jsp");
            }
        } else if ("2".equals(execMode)) {

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }
            // 課金開始日
            if (!"1".equals(chargeMode) && !isNull(startDate)) {
                warning =  "<font color='#ff0000'><b>課金開始日は指定できません</b></font>";
            }
            // 課金グループID
            if (isNull(groupId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font>";
            }
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./Recurring.jsp");
                return;
            }

            if ("1".equals(chargeMode)) {

                // 新規課金開始 //

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                RecurringAddRequestDto reqDto = new RecurringAddRequestDto();
                // 会員ID設定
                reqDto.setAccountId(accountId);
                // 課金グループID設定
                reqDto.setGroupId(groupId);
                // 課金開始日設定
                reqDto.setStartDate(startDate);
                // 課金終了日設定
                reqDto.setEndDate(endDate);
                // 都度／初回課金金額設定
                reqDto.setOneTimeAmount(oneTimeAmount);
                // 継続課金金額設定
                reqDto.setAmount(amount);
                if(!StringUtils.isEmpty(cardSelect)) {
                    // カードID
                    reqDto.setCardId(cardSelect);
                } else {
                    // トークン
                    reqDto.setToken(token);
                }

                try {
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    // コマンドを実行し、応答DTOを取得します。
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    ITransaction tran = TransactionFactory.getInstance(reqDto);
                    RecurringAddResponseDto resDto = (RecurringAddResponseDto) tran.execute();

                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./RecurringExec.jsp");

                } catch (Exception ex) {
                    // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                    System.out.println("Exception Occured !");
                    System.out.println("Exception Message: " + ex.getMessage());
                    ex.printStackTrace();
                    request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                    forward(request, response, "./RecurringExec.jsp");
                }

            } else if ("2".equals(chargeMode)) {

                // 更新 //

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                RecurringUpdateRequestDto reqDto = new RecurringUpdateRequestDto();
                // 会員ID設定
                reqDto.setAccountId(accountId);
                // 課金グループID設定
                reqDto.setGroupId(groupId);
                // 課金開始日設定
                reqDto.setStartDate(startDate);
                // 課金終了日設定
                reqDto.setEndDate(endDate);
                // 都度／初回課金金額設定
                reqDto.setOneTimeAmount(oneTimeAmount);
                // 継続課金金額設定
                reqDto.setAmount(amount);
                if(!StringUtils.isEmpty(cardSelect)) {
                    // カードID
                    reqDto.setCardId(cardSelect);
                } else {
                    // トークン
                    reqDto.setToken(token);
                }

                try {
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    // コマンドを実行し、応答DTOを取得します。
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    ITransaction tran = TransactionFactory.getInstance(reqDto);
                    RecurringUpdateResponseDto resDto = (RecurringUpdateResponseDto) tran.execute();

                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./RecurringExec.jsp");

                } catch (Exception ex) {
                    // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                    System.out.println("Exception Occured !");
                    System.out.println("Exception Message: " + ex.getMessage());
                    ex.printStackTrace();
                    request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                    forward(request, response, "./RecurringExec.jsp");
                }
            }
        } else {
            warning =  "<font color='#ff0000'><b>不正な処理です</b></font>";
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./Recurring.jsp");
                return;
            }
        }
    }
}
