package jp.veritrans.tercerog.sample.web.paypal;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.PaypalAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypalAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.PaypalCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypalCaptureResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * ペイパル決済 確定処理クラス。
 */
public class AuthorizeComplete extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException,
            IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // トークン
        String token = request.getParameter("token");
        // 顧客番号
        String payerId = request.getParameter("payerId");

        // 決済方法
        HttpSession session = request.getSession(true);
        String paymentAction = (String) session.getAttribute("paymentAction");

        try {
            if ("authorize".equals(paymentAction)) {
            // 与信のみ
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                PaypalAuthorizeRequestDto reqDto = new PaypalAuthorizeRequestDto();

                // 要求パラメータを設定します。
                // アクションの設定
                reqDto.setAction("do");
                // トークン
                reqDto.setToken(token);
                // 顧客番号
                reqDto.setPayerId(payerId);


                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                PaypalAuthorizeResponseDto resDto = (PaypalAuthorizeResponseDto) tran.execute();

                String status = resDto.getMstatus();
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                if ("success".equals(status) || "pending".equals(status)) {
                // 成功 or 保留 の場合
                    request.setAttribute("token", resDto.getToken());
                    request.setAttribute("invoiceId", resDto.getInvoiceId());
                    request.setAttribute("payerId", resDto.getPayerId());
                    request.setAttribute("amount", resDto.getAmount());
                    request.setAttribute("shipName", resDto.getShipName());
                }

                // 結果画面を表示します
                forward(request, response, "./AuthorizeComplete.jsp");
            } else {
            // 与信同時売上
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                PaypalCaptureRequestDto reqDto = new PaypalCaptureRequestDto();

                // 要求パラメータを設定します。
                // アクションの設定
                reqDto.setAction("do");
                // トークン
                reqDto.setToken(token);
                // 顧客番号
                reqDto.setPayerId(payerId);


                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                PaypalCaptureResponseDto resDto = (PaypalCaptureResponseDto) tran.execute();

                String status = resDto.getMstatus();
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                if ("success".equals(status) || "pending".equals(status)) {
                // 成功 or 保留 の場合
                    request.setAttribute("token", resDto.getToken());
                    request.setAttribute("invoiceId", resDto.getInvoiceId());
                    request.setAttribute("payerId", resDto.getPayerId());
                    request.setAttribute("amount", resDto.getAmount());
                    request.setAttribute("shipName", resDto.getShipName());
                }

                // 結果画面を表示します
                forward(request, response, "./AuthorizeComplete.jsp");
            }
        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeComplete.jsp");
        }
    }
}