package jp.veritrans.tercerog.sample.web.paypay;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.util.AuthHashUtil;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * PayPay結果通知処理クラス。
 */
public class Result extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;
    // デフォルトの文字コード
    private static final String DEFAULT_CHARSET = "UTF-8";

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // エラー情報の初期化
        String warning = null;

        // 3GPSMDK.propertiesファイルから必要な値を取得。
        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("3GPSMDK", objLcl);

        // マーチャントCCIDの取得
        String merchantCcId = rb.getString("MERCHANT_CCID");
        // マーチャントパスワードの取得
        String merchantPw = rb.getString("MERCHANT_SECRET_KEY");

        // ハッシュ値による改竄チェック
        try {
            Map requestParamMap = request.getParameterMap();

            // リクエストパラメータ（パラメータ順序、改竄チェック用ハッシュ値を含む）、
            // マーチャントCCID、マーチャントパスワード、文字コードを用いて、
            // 改竄チェックを行う。
            boolean checkResult = AuthHashUtil.checkAuthHash(requestParamMap, merchantCcId, merchantPw,
                    DEFAULT_CHARSET);
            if (!checkResult) {
                warning = "<font color='#ff0000'><b>【パラメータ改竄】パラメータ情報が改竄されています。</b></font>";
            }
        } catch (UnsupportedEncodingException e) {
            throw new ServletException("Unsupported charset : " + DEFAULT_CHARSET);
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
        }

        // 結果通知画面の表示
        forward(request, response, "./Result.jsp");
    }
}
