package jp.veritrans.tercerog.sample.web.rakuten;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RakutenReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.RakutenReAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.util.Utils;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 楽天ID決済 再与信請求処理クラス。
 */
public class ReAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {


        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 与信同時売上フラグの取得
        String withCapture = request.getParameter("withCapture");
        // 金額の取得
        String amount = request.getParameter("amount");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./ReAuthorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        RakutenReAuthorizeRequestDto reqDto = new RakutenReAuthorizeRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(request.getParameter("originalOrderId"));
        // 与信同時売上フラグの設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品番号の設定
        reqDto.setItemId(request.getParameter("itemId"));
        // 商品名の設定
        reqDto.setItemName(request.getParameter("itemName"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            RakutenReAuthorizeResponseDto resDto = (RakutenReAuthorizeResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("originalOrderId", resDto.getOriginalOrderId());
            request.setAttribute("rakutenOrderId", resDto.getRakutenOrderId());
            request.setAttribute("gatewayOrderId", resDto.getGatewayOrderId());
            request.setAttribute("rakutenConsentOrderId", resDto.getRakutenConsentOrderId());
            request.setAttribute("customerId", resDto.getCustomerId());
            request.setAttribute("usedPoint", resDto.getUsedPoint());
            request.setAttribute("cardBrand", resDto.getCardBrand());
            request.setAttribute("cardLast4", resDto.getCardLast4());
            request.setAttribute("cardInstallments", resDto.getCardInstallments());
            request.setAttribute("cardCvc", resDto.getCardCvc());
            request.setAttribute("card3ds", resDto.getCard3ds());
            request.setAttribute("transactionDatetime", resDto.getTransactionDatetime());
            request.setAttribute("cancelExpirationTime", resDto.getCancelExpirationTime());
            request.setAttribute("captureExpirationTime", resDto.getCaptureExpirationTime());
            request.setAttribute("updateExpirationTime", resDto.getUpdateExpirationTime());
            request.setAttribute("extendAuthExpirationTime", resDto.getExtendAuthExpirationTime());
            request.setAttribute("custTxn", resDto.getCustTxn());
            request.setAttribute("txnVersion", resDto.getTxnVersion());

            // 結果画面を表示します
            forward(request, response, "./ReAuthorizeExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./ReAuthorizeExec.jsp");
        }
    }

}