package jp.veritrans.tercerog.sample.web.saison.base;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.SaisonAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.SaisonAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレディセゾン決済処理クラス。
 */
public abstract class AbstractAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();
    abstract protected String getJspResult();
    abstract protected String getSettlementMethod();
    abstract protected String getMerchantRedirectionUri();
    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");

        // Captureの実行まで金額の値を伝える。
        request.getSession(true).setAttribute("amount", amount);


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (!isNum(amount)) {
            warning =  "<font color='#ff0000'><b>金額は数値で入力しなければなりません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getJsp());
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        SaisonAuthorizeRequestDto reqDto = new SaisonAuthorizeRequestDto();

        // オーダーID
        reqDto.setOrderId(orderId);
        // 決済方式（"PC"：パソコン、"MB"：モバイル、"SP"：スマートフォン）
        reqDto.setSettlementMethod(getSettlementMethod());
        // マーチャントリダイレクションURI
        reqDto.setMerchantRedirectionUri(response.encodeURL(getMerchantRedirectionUri()));

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // コマンドを実行し、応答DTOを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        ITransaction tran = TransactionFactory.getInstance(reqDto);
        SaisonAuthorizeResponseDto resDto = (SaisonAuthorizeResponseDto) tran.execute();

        if ("success".equals(resDto.getMstatus())) {
            response.setStatus(HttpServletResponse.SC_MOVED_PERMANENTLY);
            response.setHeader("Location", resDto.getResResponseContents());
        } else {
            request.setAttribute("processName", "与信");
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            forward(request, response, getJspResult());
        }
    }

    /**
     * 文字列が数値であることをチェック。
     * @param num 検査する文字列
     * @return 数値の場合はtrue
     */
    private boolean isNum(String num) {
        if (num == null || num.length() == 0) {
            return true;
        }
        try {
            Integer.parseInt(num);
        } catch (NumberFormatException e) {
            return false;
        }
        return true;
    }
}
