package jp.veritrans.tercerog.sample.web.upop;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.UpopRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.UpopRefundResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

public class RefundExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */

    protected void doProcess(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {

        String orderNumber = request.getParameter("orderId");
        String amount = request.getParameter("amount");
        
       // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderNumber)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }  
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Refund.jsp");
            return;
        }
        UpopRefundRequestDto reqDto = new UpopRefundRequestDto();
        reqDto.setOrderId(orderNumber);
        reqDto.setAmount(amount);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            UpopRefundResponseDto resDto = (UpopRefundResponseDto) tran
                    .execute();

            // 決済結果表示画面用のパラメータ設定
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("serviceType", resDto.getServiceType());
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("custTxn", resDto.getCustTxn());
            request.setAttribute("marchTxn", resDto.getMarchTxn());
            request.setAttribute("txnVersion", resDto.getTxnVersion());
            request.setAttribute("txnDatetimeJp", resDto.getTxnDatetimeJp());
            request.setAttribute("txnDatetimeCn", resDto.getTxnDatetimeCn());
            request.setAttribute("capturedAmount", resDto.getCapturedAmount());
            request.setAttribute("remainingAmount", resDto.getRemainingAmount());
            request.setAttribute("settleAmount", resDto.getSettleAmount());
            request.setAttribute("settleDate", resDto.getSettleDate());
            request.setAttribute("settleCurrency", resDto.getSettleCurrency());
            request.setAttribute("settleRate", resDto.getSettleRate());
            request.setAttribute("upopOrderId", resDto.getUpopOrderId());
            // 解析画面を表示します
            forward(request, response, "./RefundExec.jsp");
        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg",
                    "Exception Occured : " + ex.getMessage());
            forward(request, response, "./RefundExec.jsp");
        }
    }
}
