package jp.veritrans.tercerog.sample.web.virtualacc;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.VirtualaccUndoReconcileRequestDto;
import jp.veritrans.tercerog.mdk.dto.VirtualaccUndoReconcileResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 銀行振込決済消込取消請求処理クラス。
 */
public class UndoReconcileExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./UndoReconcile.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        VirtualaccUndoReconcileRequestDto reqDto = new VirtualaccUndoReconcileRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(MdkServiceConstants.VACC_RESONA);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            VirtualaccUndoReconcileResponseDto resDto = (VirtualaccUndoReconcileResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());

            // 結果画面を表示します
            forward(request, response, "./UndoReconcileExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./UndoReconcileExec.jsp");
        }
    }

}
